/****************************************************************************
** Meta object code from reading C++ file 'kdedadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kded-5.39.0/src/kdedadaptor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdedadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KdedAdaptor_t {
    QByteArrayData data[20];
    char stringdata0[255];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KdedAdaptor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KdedAdaptor_t qt_meta_stringdata_KdedAdaptor = {
    {
QT_MOC_LITERAL(0, 0, 11), // "KdedAdaptor"
QT_MOC_LITERAL(1, 12, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 28, 13), // "org.kde.kded5"
QT_MOC_LITERAL(3, 42, 10), // "loadModule"
QT_MOC_LITERAL(4, 53, 0), // ""
QT_MOC_LITERAL(5, 54, 3), // "obj"
QT_MOC_LITERAL(6, 58, 13), // "loadedModules"
QT_MOC_LITERAL(7, 72, 12), // "unloadModule"
QT_MOC_LITERAL(8, 85, 16), // "registerWindowId"
QT_MOC_LITERAL(9, 102, 8), // "windowId"
QT_MOC_LITERAL(10, 111, 12), // "QDBusMessage"
QT_MOC_LITERAL(11, 124, 18), // "unregisterWindowId"
QT_MOC_LITERAL(12, 143, 11), // "reconfigure"
QT_MOC_LITERAL(13, 155, 15), // "loadSecondPhase"
QT_MOC_LITERAL(14, 171, 4), // "quit"
QT_MOC_LITERAL(15, 176, 18), // "isModuleAutoloaded"
QT_MOC_LITERAL(16, 195, 6), // "module"
QT_MOC_LITERAL(17, 202, 22), // "isModuleLoadedOnDemand"
QT_MOC_LITERAL(18, 225, 20), // "setModuleAutoloading"
QT_MOC_LITERAL(19, 246, 8) // "autoload"

    },
    "KdedAdaptor\0D-Bus Interface\0org.kde.kded5\0"
    "loadModule\0\0obj\0loadedModules\0"
    "unloadModule\0registerWindowId\0windowId\0"
    "QDBusMessage\0unregisterWindowId\0"
    "reconfigure\0loadSecondPhase\0quit\0"
    "isModuleAutoloaded\0module\0"
    "isModuleLoadedOnDemand\0setModuleAutoloading\0"
    "autoload"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KdedAdaptor[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      11,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    1,   71,    4, 0x0a /* Public */,
       6,    0,   74,    4, 0x0a /* Public */,
       7,    1,   75,    4, 0x0a /* Public */,
       8,    2,   78,    4, 0x0a /* Public */,
      11,    2,   83,    4, 0x0a /* Public */,
      12,    0,   88,    4, 0x0a /* Public */,
      13,    0,   89,    4, 0x0a /* Public */,
      14,    0,   90,    4, 0x0a /* Public */,
      15,    1,   91,    4, 0x0a /* Public */,
      17,    1,   94,    4, 0x0a /* Public */,
      18,    2,   97,    4, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString,    5,
    QMetaType::QStringList,
    QMetaType::Bool, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::LongLong, 0x80000000 | 10,    9,    4,
    QMetaType::Void, QMetaType::LongLong, 0x80000000 | 10,    9,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QString,   16,
    QMetaType::Bool, QMetaType::QString,   16,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   16,   19,

       0        // eod
};

void KdedAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KdedAdaptor *_t = static_cast<KdedAdaptor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->loadModule((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { QStringList _r = _t->loadedModules();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->unloadModule((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->registerWindowId((*reinterpret_cast< qlonglong(*)>(_a[1])),(*reinterpret_cast< const QDBusMessage(*)>(_a[2]))); break;
        case 4: _t->unregisterWindowId((*reinterpret_cast< qlonglong(*)>(_a[1])),(*reinterpret_cast< const QDBusMessage(*)>(_a[2]))); break;
        case 5: _t->reconfigure(); break;
        case 6: _t->loadSecondPhase(); break;
        case 7: _t->quit(); break;
        case 8: { bool _r = _t->isModuleAutoloaded((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->isModuleLoadedOnDemand((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setModuleAutoloading((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject KdedAdaptor::staticMetaObject = {
    { &QDBusAbstractAdaptor::staticMetaObject, qt_meta_stringdata_KdedAdaptor.data,
      qt_meta_data_KdedAdaptor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KdedAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KdedAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KdedAdaptor.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KdedAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
