/****************************************************************************
** Meta object code from reading C++ file 'kded.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kded-5.39.0/src/kded.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kded.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Kded_t {
    QByteArrayData data[18];
    char stringdata0[198];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Kded_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Kded_t qt_meta_stringdata_Kded = {
    {
QT_MOC_LITERAL(0, 0, 4), // "Kded"
QT_MOC_LITERAL(1, 5, 10), // "loadModule"
QT_MOC_LITERAL(2, 16, 11), // "KDEDModule*"
QT_MOC_LITERAL(3, 28, 0), // ""
QT_MOC_LITERAL(4, 29, 3), // "obj"
QT_MOC_LITERAL(5, 33, 8), // "onDemand"
QT_MOC_LITERAL(6, 42, 11), // "initModules"
QT_MOC_LITERAL(7, 54, 8), // "recreate"
QT_MOC_LITERAL(8, 63, 12), // "recreateDone"
QT_MOC_LITERAL(9, 76, 14), // "updateDirWatch"
QT_MOC_LITERAL(10, 91, 18), // "updateResourceList"
QT_MOC_LITERAL(11, 110, 22), // "slotApplicationRemoved"
QT_MOC_LITERAL(12, 133, 21), // "slotKDEDModuleRemoved"
QT_MOC_LITERAL(13, 155, 10), // "dirDeleted"
QT_MOC_LITERAL(14, 166, 4), // "path"
QT_MOC_LITERAL(15, 171, 6), // "update"
QT_MOC_LITERAL(16, 178, 3), // "dir"
QT_MOC_LITERAL(17, 182, 15) // "runDelayedCheck"

    },
    "Kded\0loadModule\0KDEDModule*\0\0obj\0"
    "onDemand\0initModules\0recreate\0"
    "recreateDone\0updateDirWatch\0"
    "updateResourceList\0slotApplicationRemoved\0"
    "slotKDEDModuleRemoved\0dirDeleted\0path\0"
    "update\0dir\0runDelayedCheck"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Kded[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   69,    3, 0x0a /* Public */,
       6,    0,   74,    3, 0x0a /* Public */,
       7,    0,   75,    3, 0x0a /* Public */,
       8,    0,   76,    3, 0x0a /* Public */,
       9,    0,   77,    3, 0x0a /* Public */,
      10,    0,   78,    3, 0x0a /* Public */,
      11,    1,   79,    3, 0x0a /* Public */,
      12,    1,   82,    3, 0x0a /* Public */,
      13,    1,   85,    3, 0x09 /* Protected */,
      15,    1,   88,    3, 0x09 /* Protected */,
      17,    0,   91,    3, 0x09 /* Protected */,

 // slots: parameters
    0x80000000 | 2, QMetaType::QString, QMetaType::Bool,    4,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 2,    3,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,

       0        // eod
};

void Kded::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Kded *_t = static_cast<Kded *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { KDEDModule* _r = _t->loadModule((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< KDEDModule**>(_a[0]) = std::move(_r); }  break;
        case 1: _t->initModules(); break;
        case 2: _t->recreate(); break;
        case 3: _t->recreateDone(); break;
        case 4: _t->updateDirWatch(); break;
        case 5: _t->updateResourceList(); break;
        case 6: _t->slotApplicationRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotKDEDModuleRemoved((*reinterpret_cast< KDEDModule*(*)>(_a[1]))); break;
        case 8: _t->dirDeleted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->update((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->runDelayedCheck(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KDEDModule* >(); break;
            }
            break;
        }
    }
}

const QMetaObject Kded::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Kded.data,
      qt_meta_data_Kded,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Kded::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kded::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Kded.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kded::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}
struct qt_meta_stringdata_KBuildsycocaAdaptor_t {
    QByteArrayData data[7];
    char stringdata0[100];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KBuildsycocaAdaptor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KBuildsycocaAdaptor_t qt_meta_stringdata_KBuildsycocaAdaptor = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KBuildsycocaAdaptor"
QT_MOC_LITERAL(1, 20, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 36, 20), // "org.kde.kbuildsycoca"
QT_MOC_LITERAL(3, 57, 8), // "recreate"
QT_MOC_LITERAL(4, 66, 0), // ""
QT_MOC_LITERAL(5, 67, 17), // "isTestModeEnabled"
QT_MOC_LITERAL(6, 85, 14) // "enableTestMode"

    },
    "KBuildsycocaAdaptor\0D-Bus Interface\0"
    "org.kde.kbuildsycoca\0recreate\0\0"
    "isTestModeEnabled\0enableTestMode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KBuildsycocaAdaptor[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
       3,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    0,   31,    4, 0x0a /* Public */,
       5,    0,   32,    4, 0x0a /* Public */,
       6,    0,   33,    4, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void,

       0        // eod
};

void KBuildsycocaAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KBuildsycocaAdaptor *_t = static_cast<KBuildsycocaAdaptor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->recreate(); break;
        case 1: { bool _r = _t->isTestModeEnabled();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->enableTestMode(); break;
        default: ;
        }
    }
}

const QMetaObject KBuildsycocaAdaptor::staticMetaObject = {
    { &QDBusAbstractAdaptor::staticMetaObject, qt_meta_stringdata_KBuildsycocaAdaptor.data,
      qt_meta_data_KBuildsycocaAdaptor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KBuildsycocaAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KBuildsycocaAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KBuildsycocaAdaptor.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KBuildsycocaAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
struct qt_meta_stringdata_KUpdateD_t {
    QByteArrayData data[4];
    char stringdata0[42];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KUpdateD_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KUpdateD_t qt_meta_stringdata_KUpdateD = {
    {
QT_MOC_LITERAL(0, 0, 8), // "KUpdateD"
QT_MOC_LITERAL(1, 9, 13), // "runKonfUpdate"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 17) // "slotNewUpdateFile"

    },
    "KUpdateD\0runKonfUpdate\0\0slotNewUpdateFile"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KUpdateD[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x0a /* Public */,
       3,    1,   25,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void KUpdateD::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KUpdateD *_t = static_cast<KUpdateD *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->runKonfUpdate(); break;
        case 1: _t->slotNewUpdateFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject KUpdateD::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KUpdateD.data,
      qt_meta_data_KUpdateD,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KUpdateD::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KUpdateD::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KUpdateD.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KUpdateD::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
